<?php

add_action('after_setup_theme', 'interiors_setup');
function interiors_setup()
{
    load_theme_textdomain('interiors', get_template_directory() . '/languages');
    
    $args = array(
        'flex-width' => true,
        'width' => 950,
        'flex-height' => true,
        'height' => 419,
        'default-image' => get_template_directory_uri() . '/images/interiors.jpg',
        'uploads' => true
    );
    
    add_theme_support('custom-header', $args);
    
    add_theme_support('automatic-feed-links');
    
    add_theme_support('post-thumbnails');
    
    add_theme_support('custom-background');
    
    global $content_width;
    if (!isset($content_width))
        $content_width = 438;
    
    register_nav_menus(array(
        'main' => __('Main Menu', 'interiors')
    ));
    
    add_editor_style('custom-editor-style.css');
}



add_action('comment_form_before', 'interiors_enqueue_comment_reply_script');
function interiors_enqueue_comment_reply_script()
{
    if (get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}
add_filter('the_title', 'interiors_title');
function interiors_title($title)
{
    if ($title == '') {
        return '&rarr;';
    } else {
        return $title;
    }
}
function interiors_customize_register($wp_customize)
{
    $wp_customize->add_setting('logo_image', array(
        'flex-width' => true,
        'width' => 300,
        'flex-height' => true,
        'height' => 75,
        'default-image' => '',
        'uploads' => true,
        'sanitize_callback' => 'esc_url_raw'
    ));
    
    $wp_customize->add_section('interiors_logo_image', array(
        'title' => __('Logo Image', 'interiors'),
        'priority' => 30
    ));
    
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'logo', array(
        'label' => __('Upload a logo image', 'interiors'),
        'section' => 'interiors_logo_image',
        'settings' => 'logo_image',
        'context' => 'normal'
    )));
    
    $wp_customize->add_setting('light_color', array(
        'default' => '#f8e7d4',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'light_color', array(
        'label' => 'Lighter Background Color',
        'section' => 'colors',
        'settings' => 'light_color'
    )));
    
}

add_action( 'wp_enqueue_scripts', 'interiors_load_scripts' );
function interiors_load_scripts()
{
wp_enqueue_style( 'style', get_stylesheet_uri() );
}

add_action('customize_register', 'interiors_customize_register');

function interiors_customize_css()
{
?>
         <style type="text/css">
             #footer, #top-search form #s { background-color: <?php
    echo get_theme_mod('light_color', '#f8e7d4');
?>  }
              
</style>
    <?php
}
add_action('wp_head', 'interiors_customize_css');
add_filter('wp_title', 'interiors_filter_wp_title');
function interiors_filter_wp_title($title)
{
    return $title . esc_attr(get_bloginfo('name'));
}
add_action('widgets_init', 'interiors_widgets_init');
function interiors_widgets_init()
{
    register_sidebar(array(
        'name' => __('sidebar', 'interiors'),
        'id' => 'primary-widget-area',
        'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
        'after_widget' => "</li>",
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>'
    ));
    
    register_sidebar(array(
        'name' => __('Right Widget Area', 'interiors'),
        'id' => 'secondary-widget-area',
        'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
        'after_widget' => "</li>",
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>'
    ));
    
    register_sidebar(array(
        'name' => __('First Front Page Div', 'interiors'),
        'id' => 'first-page-div',
        'before_widget' => '<div class="column" id="first-column">',
        'after_widget' => "</div>",
        'before_title' => '<h2>',
        'after_title' => '</h2>'
    ));
    
    register_sidebar(array(
        'name' => __('Second Front Page Div', 'interiors'),
        'id' => 'second-page-div',
        'before_widget' => '<div class="column" id="second-column">',
        'after_widget' => "</div>",
        'before_title' => '<h2>',
        'after_title' => '</h2>'
    ));
    
    register_sidebar(array(
        'name' => __('Third Front Page Div', 'interiors'),
        'id' => 'third-page-div',
        'before_widget' => '<div class="column">',
        'after_widget' => "</div>",
        'before_title' => '<h2>',
        'after_title' => '</h2>'
    ));
    
    register_sidebar(array(
        'name' => __('First Footer Column', 'interiors'),
        'id' => 'first-footer-div',
        'before_widget' => '<ul class="xoxo"><li id="%1$s" class="widget-container %2$s">',
        'after_widget' => "</li></ul>",
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>'
    ));
    
    register_sidebar(array(
        'name' => __('Second Footer Column', 'interiors'),
        'id' => 'second-footer-div',
        'before_widget' => '<ul class="xoxo"><li id="%1$s" class="widget-container %2$s">',
        'after_widget' => "</li></ul>",
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>'
    ));
    
    
    register_sidebar(array(
        'name' => __('Third Footer Column', 'interiors'),
        'id' => 'third-footer-div',
        'before_widget' => '<ul class="xoxo"><li id="%1$s" class="widget-container %2$s">',
        'after_widget' => "</li></ul>",
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>'
    ));
    
    register_sidebar(array(
        'name' => __('Fourth Footer Column', 'interiors'),
        'id' => 'fourth-footer-div',
        'before_widget' => '<ul class="xoxo"><li id="%1$s" class="widget-container %2$s">',
        'after_widget' => "</li></ul>",
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>'
    ));
    
    
}
function interiors_custom_pings($comment)
{
    $GLOBALS['comment'] = $comment;
?>
<li <?php
    comment_class();
?> id="li-comment-<?php
    comment_ID();
?>"><?php
    echo comment_author_link();
?></li>
<?php
}
add_filter('get_comments_number', 'interiors_comments_number');
function interiors_comments_number($count)
{
    if (!is_admin()) {
        global $id;
        $get_comments = get_comments('status=approve&post_id=' . $id);
        
        $comments_by_type = separate_comments($get_comments);
        
        return count($comments_by_type['comment']);
    } else {
        
        return $count;
        
    }
}